summaryrefslogtreecommitdiff
path: root/text.h
diff options
context:
space:
mode:
Diffstat (limited to 'text.h')
-rw-r--r--text.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/text.h b/text.h
index ff07e79..8b2f133 100644
--- a/text.h
+++ b/text.h
@@ -41,8 +41,8 @@ typedef struct {
/// largest y achieved (for computing size)
double y_largest;
- /// previous character rendered, or 0 if this is the first
- char32_t prev_char;
+ /// index of previous glyph rendered, or 0 if this is the first
+ int prev_glyph;
/// used for forwards-compatibility
char _reserved[64];